#!/bin/bash

# Automates the packaging process of the software "fontconfig" for
# use with Zenwalk Linux.
#	
# Copyright (C) 2008 Michael Verret <michael.verret@gmail.com>

# Summary: Font configuration and customization library
# License: MIT
# Group: Libraries/X
# URL: http://fontconfig.org
# Runtime dependencies: expat,freetype,zlib


# Variables:
#_______________________________________________________________________



Build_Root=$(pwd)

Software_Name="fontconfig"
Software_Version="2.6.0"
Package_Build="62.1"

Flag_Arch='i686'

Standard_Docs="AUTHORS BUGS COPYING ChangeLog INSTALL LICENSE NEWS README"

Installation_Root="${Build_Root}/${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}"

Source_00_Title="${Software_Name}-${Software_Version}"

Source_00_URL="http://cgit.freedesktop.org/fontconfig/snapshot/fontconfig-2.6.0.tar.bz2"

Patch_00="zenwalk-fontconfig-2.6.0-font.dir.list.diff.gz"
Patch_01="zenwalk-fontconfig-2.6.0-prefer-dejavu-ttf-fonts.diff.gz"
Patch_02="zenwalk-fontconfig-2.6.0-prefer-liberation-fonts.diff.gz"

Script_00="build-${Software_Name}.sh"
Script_01="setup.05.fontconfig.gz"

Binary_Pkg_String="${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}"
Source_Pkg_String="${Software_Name}-${Software_Version}-${Flag_Arch}-${Package_Build}-src"

Binary_Install_Root="${Build_Root}/${Binary_Pkg_String}"
Source_Install_Root="${Build_Root}/${Source_Pkg_String}"



# Clean & Prep:
#_______________________________________________________________________



# Pre Build Cleanup
	cd ${Build_Root}
	Old_Files=" \
		${Installation_Root} \
		${Binary_Pkg_String}* \
		${Source_Pkg_String}*"
	for Unneeded in ${Old_Files} ; do
		if [ -e ${Unneeded} ] ; then
			rm -rf ${Unneeded}
		fi
	done
# Create Installation_Root
	mkdir ${Installation_Root}
# Add a package description file:
mkdir -p ${Installation_Root}/install
cat <<EOF0 > ${Binary_Pkg_String}/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
fontconfig: fontconfig (Font configuration and customization library)
fontconfig:
fontconfig: Fontconfig is a library designed to provide system-wide font
fontconfig: configuration, customization, and application access.
fontconfig: Fontconfig is written and maintained by Keith Packard.
fontconfig: maintained by Keith Packard.
fontconfig: Fontconfig is distributed under a permissive free software
fontconfig: licence, and is thus free software.
fontconfig:
fontconfig:
fontconfig:
EOF0
# Install build scripts and patches:
	mkdir -p ${Installation_Root}/usr/src/${Software_Name}-${Software_Version}
	cp \
		${Patch_00} \
		${Patch_01} \
		${Patch_02} \
		${Script_00} \
		${Script_01} \
		${Installation_Root}/usr/src/${Software_Name}-${Software_Version}/



# Build fontconfig
#_______________________________________________________________________


if [ -e ${Source_00_Title}.tar.bz2 ] ; then
		echo "${Source_00_Title}.tar.bz2 is here, life is good!"
else
	wget -c -t 0 -T 50 -w 0 ${Source_00_URL} || exit 1
fi

# Clean:
	cd ${Build_Root}
	rm -rf ${Source_00_Title}
# Extract:
for Archive in ${Source_00_Title}.tar.bz2 ; do
	File_Type=$(file -biz "${Archive}")
	unset Command
	case "${File_Type}" in
		*application/x-tar*)
			Command="tar -xf" ;;
		*application/x-zip*)
			Command="unzip" ;;
		*application/x-gzip*)
			Command="gunzip -d -f" ;;
		*application/x-bzip*)
			Command="bunzip2 -f" ;;
	esac
	if [ "$Command" != "" ]; then
		echo "${Command} ${Archive}"
		${Command} ${Archive} || exit 1
	fi
done
# Enter:
	cd ${Source_00_Title}
# Ensure proper permissions and ownership:
	chown -R root:root .
	find . -perm 666 -exec chmod 644 {} \;  
	find . -perm 664 -exec chmod 644 {} \;
	find . -perm 600 -exec chmod 644 {} \;
	find . -perm 444 -exec chmod 644 {} \;
	find . -perm 400 -exec chmod 644 {} \;
	find . -perm 440 -exec chmod 644 {} \;
	find . -perm 777 -exec chmod 755 {} \;
	find . -perm 775 -exec chmod 755 {} \;
	find . -perm 511 -exec chmod 755 {} \;
	find . -perm 711 -exec chmod 755 {} \;
	find . -perm 555 -exec chmod 755 {} \;
# Hardcode the default font search path rather than having fontconfig
# figure it out (and possibly follow symlinks, or index ugly bitmapped
# fonts):
	zcat ../${Patch_00} | patch -p1 --verbose || exit 1
# Make dejavu-ttf and liberation fonts preferred over Bitstream Vera fonts:
	zcat ../${Patch_01} | patch -p1 --verbose || exit 1
	zcat ../${Patch_02} | patch -p1 --verbose || exit 1
# We don't want to rebuild the docs, but we want to install the included ones.
	export HASDOCBOOK=no
# Configuration:
	./autogen.sh \
	CFLAGS="-O2 -march=${Flag_Arch} -pipe"\
	CXXFLAGS="${CFLAGS}"\
	PKG_CONFIG_PATH=/usr/lib/pkgconfig \
	--prefix=/usr \
	--mandir=/usr/man \
	--sysconfdir=/etc \
	--localstatedir=/var \
	--silent
# Compilation:
	make --silent || exit 1
	make check || exit 1
# Installation:
	make install --silent  DESTDIR=${Installation_Root} || exit 1
# Documentation:
	mkdir -p ${Installation_Root}/usr/doc/
	(
		cd ${Installation_Root}/usr/
		mv share/doc/fontconfig doc/${Source_00_Title}/
		rmdir share/doc share
	)
	for Doc in ${Standard_Docs} ; do
		if [ -e ${Doc} ] ; then
			cp ${Doc} ${Installation_Root}/usr/doc/${Source_00_Title}/
		fi
	done
	(
		cd ${Installation_Root}/usr/doc/${Source_00_Title}/
		find . -name "*" -size 0c -exec rm {} \;
	)
# Move pkgconfig To Be Safe:
	if [ ! -d ${Installation_Root}/usr/lib/pkgconfig ]; then
		mkdir -p ${Installation_Root}/usr/lib/pkgconfig
		mv ${Installation_Root}/usr/lib/pkgconfig/* ${Installation_Root}/usr/lib/pkgconfig
		rmdir ${Installation_Root}/usr/lib/pkgconfig
	fi
# Add setup File:
	mkdir -p ${Installation_Root}/var/log/setup
	zcat ${Build_Root}/${Script_01} > ${Installation_Root}/var/log/setup/setup.05.fontconfig
	chmod 755 ${Installation_Root}/var/log/setup/setup.05.fontconfig
# Set up the default options in /etc/fonts/conf.d:
	(
		cd ${Installation_Root}/etc/fonts/conf.d
		for Config in \
			20-fix-globaladvance.conf \
			20-unhint-small-vera.conf \
			30-urw-aliases.conf \
			30-metric-aliases.conf \
			40-nonlatin.conf \
			45-latin.conf \
			49-sansserif.conf \
			50-user.conf \
			51-local.conf \
			60-latin.conf \
			65-fonts-persian.conf \
			65-nonlatin.conf \
			69-unifont.conf \
			80-delicious.conf \
			90-synthetic.conf ; do
			ln -sf ../conf.avail/${Config} . || exit 1
		done
		if [ ! $? = 0 ]; then
			exit 1
		fi
	)
	if [ ! $? = 0 ]; then
		echo "Missing /etc/fonts/$fontconf default.  Exiting"
		exit 1
	fi
# Add a post-install routine
	cat << EOF1 > ${Installation_Root}/install/doinst.sh
#!/bin/sh
# Update the X font indexes:
if [ -x /usr/bin/fc-cache ]; then
  /usr/bin/fc-cache -f 1>/dev/null 2>&1
fi
# else we'll catch it later with setup.fontconfig :-)
# make links:
EOF1
# Compress and if needed symlink the man pages.
	if [ -d ${Installation_Root}/usr/man ]; then
		(
			cd ${Installation_Root}/usr/man
			for Man_Page_Dir in $(find . -type d -name "man*") ; do
				(
					cd ${Man_Page_Dir}
					for Each_Page in $( find . -type l -maxdepth 1) ; do
						ln -s $( readlink ${Each_Page} ).gz ${Each_Page}.gz
						rm ${Each_Page}
					done
					gzip -9 *.?
				)
			done
		)
	fi
# Clean:
	cd ${Build_Root}
	rm -rf ${Source_00_Title}



# Packaging:
#_______________________________________________________________________



# Strip Binaries:
	(
		cd ${Installation_Root}
		find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
		find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
	)
# Compress The Package:
    (
      cd ${Installation_Root}
      makepkg -l y -c n ${Build_Root}/${Binary_Pkg_String}.tgz
    )
# Create dep file:
	(
		cd ${Build_Root}
		depfinder -f ${Binary_Pkg_String}.tgz > ${Binary_Pkg_String}.dep
	)
# Calculate The MD5 Sum:
    (
      cd ${Build_Root}
      md5sum ${Binary_Pkg_String}.tgz > ${Binary_Pkg_String}.md5
      rm -rf ${Binary_Pkg_String}
    )
# Create a source package and checksum:
	cd ${Build_Root}
	mkdir ${Binary_Pkg_String}-src
	cp \
		${Source_00_Title}.tar.bz2 ${Patch_00} ${Patch_01} \
		${Patch_02} ${Script_00} ${Binary_Pkg_String}-src
	tar jcf ${Binary_Pkg_String}-src.tbz ${Binary_Pkg_String}-src
	md5sum ${Binary_Pkg_String}-src.tbz > ${Binary_Pkg_String}-src.md5
# Post Build Cleanup
	cd ${Build_Root}
	Old_Directories=" \
		${Installation_Root} \
		${Binary_Pkg_String}-src"
	for Unneeded in ${Old_Directories} ; do
		if [ -e ${Unneeded} ] ; then
			rm -rf ${Unneeded}
		fi
	done



# Changelog:
#_______________________________________________________________________


# ~ Fri Mar 13th 2009	Michael Verret "axxium"<michael.verret@gmail.com>
# ~ Rebuilt against gcc-4.3.3.

# ~ Sat Aug 23 2008	Michael Verret "axxium"<michael.verret@gmail.com>
# ~ Edited build script per new layout.

# ~ Wed Jun 18 2008	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Updated: fontconfig-2.6.0

# ~ Wed May 21 2008	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Updated: fontconfig-2.5.92

# ~ Tue Dec 04 2007	Michael Verret "axxium" <michael.verret@gmail.com>
# ~ Initial build.
# ~ Updated: fontconfig-2.4.2
